﻿#ifndef _WTL_TEST_PLUGIN_H_
#define _WTL_TEST_PLUGIN_H_

#include "MQBasePlugin.h"

class WTLTestPlugin : public MQStationPlugin
{
	friend class CMainDlg;

protected:
	CMainDlg *dlgMain;
	bool m_bActivate;

public:
	bool m_bShowLocal;

public:
	WTLTestPlugin();
	virtual ~WTLTestPlugin();

	// プラグインIDを返す。
	void GetPlugInID(DWORD *Product, DWORD *ID) override;
	// プラグイン名を返す。
	const char *GetPlugInName(void) override;
	// ポップアップメニューに表示される文字列を返す。
	const wchar_t *EnumString(void) override;

	// アプリケーションの初期化
	BOOL Initialize() override;
	// アプリケーションの終了
	void Exit() override;

	// 表示・非表示切り替え要求
	BOOL Activate(MQDocument doc, BOOL flag) override;
	// 表示・非表示状態の返答
	BOOL IsActivated(MQDocument doc) override;

	// ドキュメント初期化時
	void OnNewDocument(MQDocument doc, const char *filename, NEW_DOCUMENT_PARAM& param) override;
	// ドキュメント保存時
	void OnSaveDocument(MQDocument doc, const char *filename, SAVE_DOCUMENT_PARAM& param) override;
	// 描画時の処理
	void OnDraw(MQDocument doc, MQScene scene, int width, int height) override;
	// オブジェクトの編集時
	void OnObjectModified(MQDocument doc) override;
	// カレントオブジェクトの変更時
	void OnUpdateObjectList(MQDocument doc) override;


	typedef bool (WTLTestPlugin::*ExecuteCallbackProc)(MQDocument doc);

	void Execute(ExecuteCallbackProc proc);

	// 面の削除
	bool DeleteFace(MQDocument doc);

protected:
	struct CallbackInfo {
		ExecuteCallbackProc proc;
	};

	bool ExecuteCallback(MQDocument doc, void *option) override;
};


#endif _WTL_TEST_PLUGIN_H_
